@@ -1,11 +1,9 @@
 package CGI::Lazy::Plugin;
 
 use strict;
-use warnings;
 
 use CGI::Lazy::Globals;
 
-no warnings qw(uninitialized redefine);
 #-------------------------------------------------------------------------------
 sub AUTOLOAD {
 	my $self = shift;
